==> sqlitestudio-3.0.7.tar.gz: Plugins/XmlExport/XmlExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>XmlExport</name>
    <message>
        <location filename="xmlexport.cpp" line="38"/>
        <source>Enter the namespace to use (for example: http://my.namespace.org)</source>
        <translation>Saississez l&apos;espace nom (par exemple: http://my.namespace.org)</translation>
    </message>
</context>
<context>
    <name>XmlExportConfig</name>
    <message>
        <location filename="XmlExport.ui" line="20"/>
        <source>Output format</source>
        <translation>Format de sortie</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="26"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Format document( nouvelle lignes, indentation)</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="42"/>
        <source>Compress (everything in one line)</source>
        <translation>Compression (tout en une ligne)</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="58"/>
        <source>Special characters escaping</source>
        <translation>Caractères spécial d&apos;échappement</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="64"/>
        <source>&lt;p&gt;Ampersands will be used for shorter values and CDATA will be used for larger values. This applies only to values that require character escaping. Other values will be exported as they are.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Esperluette sera utilisée pourpour les valeurs les plus courtes et CDATA pour les plus longues. Ceci appliqué seulement aux valeurs qui requirent un caractère d&apos;échapement. Les autres valeurs seront exportées telque.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="67"/>
        <source>Use CDATA and ampersands</source>
        <translation>Utiliser esperluettes et CDATA</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="83"/>
        <source>&lt;p&gt;Every value requiring character escepe will be enclosed in CDATA block.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Toute valeur requierant un carctère d&apos;échappement sera incluse dans le block CDATA.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="86"/>
        <source>Always use CDATA</source>
        <translation>Toujours utiliser CDATA</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="99"/>
        <source>&lt;p&gt;Every character that require esceping will be replaced with its ampersand escape sequence. No CDATA blocks will be used.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Chaque caractère  requirant un échappement sera encadré avec  une séquence esperluette.Aucun  block CDATA ne sera utilisé&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="102"/>
        <source>Always use ampersand</source>
        <translation>Toujours utiliser esperluette</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="118"/>
        <source>Define XML namespace</source>
        <translation>Définir le domaine XML</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/XmlExport/XmlExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>XmlExport</name>
    <message>
        <location filename="xmlexport.cpp" line="38"/>
        <source>Enter the namespace to use (for example: http://my.namespace.org)</source>
        <translation>Saississez l&rsquo;espace nom (par exemple: http://my.namespace.org)</translation>
    </message>
</context>
<context>
    <name>XmlExportConfig</name>
    <message>
        <location filename="XmlExport.ui" line="20"/>
        <source>Output format</source>
        <translation>Format de sortie</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="26"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Format document( nouvelle lignes, indentation)</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="42"/>
        <source>Compress (everything in one line)</source>
        <translation>Compression (tout en une ligne)</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="58"/>
        <source>Special characters escaping</source>
        <translation>Caractères spécial d&rsquo;échappement</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="64"/>
        <source>&lt;p&gt;Ampersands will be used for shorter values and CDATA will be used for larger values. This applies only to values that require character escaping. Other values will be exported as they are.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Esperluette sera utilisée pourpour les valeurs les plus courtes et CDATA pour les plus longues. Ceci appliqué seulement aux valeurs qui requirent un caractère d&rsquo;échapement. Les autres valeurs seront exportées telque.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="67"/>
        <source>Use CDATA and ampersands</source>
        <translation>Utiliser esperluettes et CDATA</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="83"/>
        <source>&lt;p&gt;Every value requiring character escepe will be enclosed in CDATA block.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Toute valeur requierant un carctère d&rsquo;échappement sera incluse dans le block CDATA.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="86"/>
        <source>Always use CDATA</source>
        <translation>Toujours utiliser CDATA</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="99"/>
        <source>&lt;p&gt;Every character that require esceping will be replaced with its ampersand escape sequence. No CDATA blocks will be used.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Chaque caractère requirant un échappement sera encadré avec une séquence esperluette.Aucun block CDATA ne sera utilisé&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="102"/>
        <source>Always use ampersand</source>
        <translation>Toujours utiliser esperluette</translation>
    </message>
    <message>
        <location filename="XmlExport.ui" line="118"/>
        <source>Define XML namespace</source>
        <translation>Définir le domaine XML</translation>
    </message>
</context>
</TS>
